@@ -1,9 +1,10 @@
+# TODO: release on Anaconda
 from .document import Document
 from .exception import LivemarkException
 from .markup import Markup
 from .plugin import Plugin
 from .program import program
-from .project import Project
+from .server import Server
 from .settings import VERSION as __version__
 from .snippet import Snippet
 from .system import system
