@@ -1,9 +1,27 @@
 from pyquery import PyQuery
+from contextlib import contextmanager
 from .exception import LivemarkException
 from . import helpers
 
 
+# NOTE:
+# PyQuery uses lxml which esape all the <> inside the tags
+# In markup.output we recover initial formatting for styles and scripts
+# Take into account that this method is fragile and might need to be rewrited
+
+
 class Markup:
+    """Livemark markup
+
+    API      | Usage
+    -------- | --------
+    Public   | `from livemark import Markup`
+
+    Parameters:
+        input (str): html input for the markup
+
+    """
+
     def __init__(self, input):
         self.__input = input
         self.__query = PyQuery(input)
@@ -12,13 +30,6 @@ class Markup:
         self.__styles = set()
         self.__scripts = set()
 
-    def __enter__(self):
-        assert self.plugin
-        return self
-
-    def __exit__(self, type, value, traceback):
-        self.bind()
-
     @property
     def input(self):
         return self.__input
@@ -29,10 +40,6 @@ class Markup:
 
     @property
     def output(self):
-        # NOTE:
-        # PyQuery uses lxml which esape all the <> inside the tags
-        # Here we recover initial formatting for styles and scripts
-        # Take into account that this script is fragile (needs rewriting)
         lines = []
         is_replacing = False
         output = self.__query.outer_html()
@@ -47,6 +54,8 @@ class Markup:
         output = "".join(lines)
         return output
 
+    # Process
+
     def process(self, document):
         for plugin in document.plugins:
             with self.bind(plugin):
@@ -54,42 +63,46 @@ class Markup:
 
     # Bind
 
+    @contextmanager
     def bind(self, plugin=None):
         if callable(plugin):
             plugin = plugin.__self__
         self.__plugin = plugin
-        return self
-
-    @property
-    def plugin(self):
-        if not self.__plugin:
-            raise LivemarkException("The object is not bound to any plugin")
-        return self.__plugin
+        yield self.__plugin
+        self.__plugin = None
 
     # Helpers
 
     def add_style(self, source, *, action="append", target="head", **context):
+        plugin = self.get_plugin()
         style = f'<link rel="stylesheet" href="{source}"></script>\n'
         if not helpers.is_remote_path(source):
-            style = self.plugin.read_asset(source, **context)
+            style = plugin.read_asset(source, **context)
             style = f"<style>\n\n{style}\n\n</style>\n"
         if style in self.__styles:
             return
         self.__styles.add(style)
-        getattr(self.query(target), action)(style)
+        getattr(self.__query(target), action)(style)
 
     def add_script(self, source, *, action="append", target="body", **context):
+        plugin = self.get_plugin()
         script = f'<script src="{source}"></script>\n'
         if not helpers.is_remote_path(source):
-            script = self.plugin.read_asset(source, **context)
+            script = plugin.read_asset(source, **context)
             script = f"<script>\n\n{script}\n\n</script>\n"
         if script in self.__scripts:
             return
         self.__scripts.add(script)
-        getattr(self.query(target), action)(script)
+        getattr(self.__query(target), action)(script)
 
     def add_markup(self, source, *, action="append", target="body", **context):
         markup = source
+        plugin = self.get_plugin()
         if not source.strip().startswith("<"):
-            markup = self.plugin.read_asset(source, **context)
-        getattr(self.query(target), action)(f"\n{markup}\n")
+            markup = plugin.read_asset(source, **context)
+        getattr(self.__query(target), action)(f"\n{markup}\n")
+
+    def get_plugin(self):
+        if not self.__plugin:
+            raise LivemarkException("The object is not bound to any plugin")
+        return self.__plugin
